summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndroid Build Coastguard Worker <android-build-coastguard-worker@google.com>2021-06-25 01:07:12 +0000
committerAndroid Build Coastguard Worker <android-build-coastguard-worker@google.com>2021-06-25 01:07:12 +0000
commit4b986afbc79f3839456096cb483d83aa3b3ff8e8 (patch)
treee99b1603dfe3fe7cf16d5b2e415cde77979fbbdc
parent0ad1b473ad440bfd54fbab7289173be0eca70b06 (diff)
parenta20206ab1c049b005d9f624f5558a28e10a63d51 (diff)
downloadav-android12-d1-s1-release.tar.gz
Change-Id: Icb74e6df2e703d7c04b4688abc83e9ab2874e3f7
-rw-r--r--media/eco/ECOSession.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/media/eco/ECOSession.cpp b/media/eco/ECOSession.cpp
index a7b919f..ea5d552 100644
--- a/media/eco/ECOSession.cpp
+++ b/media/eco/ECOSession.cpp
@@ -53,10 +53,10 @@ using android::sp;
// static
sp<ECOSession> ECOSession::createECOSession(int32_t width, int32_t height, bool isCameraRecording) {
// Only support up to 720P.
// TODO: Support the same resolution as in EAF.
if (width <= 0 || height <= 0 || width > 5120 || height > 5120 ||
- width > 1280 * 720 / height) {
+ width > 1920 * 1080 / height) {
ECOLOGE("Failed to create ECOSession with w: %d, h: %d, isCameraRecording: %d", width,
height, isCameraRecording);
return nullptr;
@@ -53,10 +53,10 @@ using android::sp;
// static
sp<ECOSession> ECOSession::createECOSession(int32_t width, int32_t height, bool isCameraRecording) {
- // Only support up to 720P.
+ // Only support up to 1080P.
// TODO: Support the same resolution as in EAF.
if (width <= 0 || height <= 0 || width > 5120 || height > 5120 ||